bibentry(bibtype = "Misc",
         key = "Blake+Merz:1998",
         author = c(person(given = c("C.", "L."),
                           family = "Blake"),
                    person(given = c("C.", "J."),
                           family = "Merz")),
         title = "{UCI} Repository of Machine Learning Databases",
         year = "1998",
         note = "University of California, Irvine, Department of Information and Computer Science.  Formerly available from \\samp{http://www.ics.uci.edu/~mlearn/MLRepository.html}")

bibentry(bibtype = "Article",
         key = "Breiman:1996",
         title = "Bagging Predictors",
         volume = "24",
         .issn = "1573-0565",
         doi = "10.1023/a:1018054314350",
         number = "2",
         journal = "Machine Learning",
         publisher = "Springer Science and Business Media LLC",
         author = person(given = "Leo",
                         family = "Breiman"),
         year = "1996",
         month = "aug",
         pages = "123--140")

bibentry(bibtype = "TechReport",
         key = "Breiman:1996b",
         author = person(given = "Leo",
                         family = "Breiman"),
         title = "Bias, Variance, and Arcing Classifiers",
         institution = "Statistics Department, University of California, Berkeley",
         year = "1996",
         number = "460",
         url = "https://www.stat.berkeley.edu/~breiman/arcall96.pdf")

bibentry(bibtype = "Article",
         key = "Breiman+Friedman:1985",
         author = c(person(given = "Leo",
                           family = "Breiman"),
                    person(given = c("Jerome", "H."),
                           family = "Friedman")),
         title = "Estimating Optimal Transformations for Multiple Regression and Correlation",
         journal = "Journal of the American Statistical Association",
         volume = "80",
         number = "391",
         pages = "580--598",
         year = "1985",
         publisher = "Taylor \\& Francis",
         doi = "10.1080/01621459.1985.10478157",
         url = "https://doi.org/10.1080/01621459.1985.10478157",
         eprint = "https://doi.org/10.1080/01621459.1985.10478157")

bibentry(bibtype = "PhdThesis",
         key = "Deterding:1990",
         author = person(given = "David",
                         family = "Deterding"),
         title = "Speaker Normalisation for Automatic Speech Recognition",
         school = "University of Cambridge",
         year = "1990")

bibentry(bibtype = "InCollection",
         key = "Fisher+Schlimmer:1988",
         title = "Concept Simplification and Prediction Accuracy",
         editor = person(given = "John",
                         family = "Laird"),
         booktitle = "Machine Learning Proceedings 1988",
         publisher = "Morgan Kaufmann",
         address = "San Francisco (CA)",
         pages = "22--28",
         year = "1988",
         isbn = "978-0-934613-64-4",
         doi = "10.1016/B978-0-934613-64-4.50007-4",
         author = c(person(given = c("Douglas", "H."),
                           family = "Fisher"),
                    person(given = c("Jeffrey", "C."),
                           family = "Schlimmer")))

bibentry(bibtype = "Article",
         key = "Frey+Slate:1991",
         author = c(person(given = c("Peter", "W."),
                           family = "Frey"),
                    person(given = c("David", "J."),
                           family = "Slate")),
         title = "Letter Recognition Using {Holland}-Style Adaptive Classifiers",
         journal = "Machine Learning",
         year = "1991",
         volume = "6",
         pages = "161--182",
         doi = "10.1007/BF00114162")

bibentry(bibtype = "Article",
         key = "Friedman:1991",
         author = person(given = c("Jerome", "H."),
                         family = "Friedman"),
         title = "{Multivariate Adaptive Regression Splines}",
         volume = "19",
         journal = "The Annals of Statistics",
         number = "1",
         publisher = "Institute of Mathematical Statistics",
         pages = "1--67",
         year = "1991",
         doi = "10.1214/aos/1176347963")

bibentry(bibtype = "Article",
         key = "Gilley+Pace:1996",
         title = "On the {Harrison and Rubinfeld} Data",
         journal = "Journal of Environmental Economics and Management",
         volume = "31",
         number = "3",
         pages = "403--405",
         year = "1996",
         issn = "0095-0696",
         doi = "10.1006/jeem.1996.0052",
         author = c(person(given = c("Otis", "W."),
                           family = "Gilley"),
                    person(given = c("R.", "Kelley"),
                           family = "Pace")))

bibentry(bibtype = "Article",
         key = "Gorman+Sejnowski:1988",
         title = "Analysis of Hidden Units in a Layered Network Trained to Classify Sonar Targets",
         journal = "Neural Networks",
         volume = "1",
         number = "1",
         pages = "75--89",
         year = "1988",
         issn = "0893-6080",
         doi = "10.1016/0893-6080(88)90023-8",
         author = c(person(given = c("R.", "Paul"),
                           family = "Gorman"),
                    person(given = c("Terrence", "J."),
                           family = "Sejnowski")))

bibentry(bibtype = "Article",
         key = "Harrison+Rubinfeld:1978",
         title = "Hedonic Housing Prices and the Demand for Clean Air",
         journal = "Journal of Environmental Economics and Management",
         volume = "5",
         number = "1",
         pages = "81--102",
         year = "1978",
         issn = "0095-0696",
         doi = "10.1016/0095-0696(78)90006-2",
         author = c(person(given = "David",
                           family = "Harrison"),
                    person(given = c("Daniel", "L."),
                           family = "Rubinfeld")))

bibentry(bibtype = "Article",
         key = "Michalski+Chilausky:1980",
         author = c(person(given = c("R.", "S."),
                           family = "Michalski"),
                    person(given = c("R.", "L."),
                           family = "Chilausky")),
         title = "Learning by Being Told and Learning from Examples: An Experimental Comparison of the Two Methods for Knowledge Acquisition in the Context of Developing an Expert System for Soybean Disease Diagnosis",
         journal = "International Journal of Policy Analysis and Information Systems",
         year = "1980",
         volume = "4",
         number = "2",
         pages = "125--161")

bibentry(bibtype = "Article",
         key = "Niranjan+Fallside:1990",
         title = "Neural Networks and Radial Basis Functions in Classifying Static Speech Patterns",
         journal = "Computer Speech & Language",
         volume = "4",
         number = "3",
         pages = "275--289",
         year = "1990",
         issn = "0885-2308",
         doi = "10.1016/0885-2308(90)90009-U",
         author = c(person(given = "Mahesan",
                           family = "Niranjan"),
                    person(given = "Frank",
                           family = "Fallside")))

bibentry(bibtype = "InProceedings",
         key = "Noordewier+Towell+Shavlik:1990",
         author = c(person(given = c("Michiel", "O."),
                           family = "Noordewier"),
                    person(given = c("Geoffrey", "G."),
                           family = "Towell"),
                    person(given = c("Jude", "W."),
                           family = "Shavlik")),
         title = "Training Knowledge-Based Neural Networks to Recognize Genes in {DNA} Sequences",
         year = "1990",
         isbn = "1558601848",
         publisher = "Morgan Kaufmann Publishers Inc.",
         address = "San Francisco, CA, USA",
         booktitle = "Proceedings of the 4th International Conference on Neural Information Processing Systems",
         pages = "530--536",
         numpages = "7",
         location = "Denver, Colorado",
         series = "NIPS'90")

bibentry(bibtype = "Article",
         key = "Pace+Gilley:1997",
         author = c(person(given = c("R.", "Kelley"),
                           family = "Pace"),
                    person(given = c("Otis", "W."),
                           family = "Gilley")),
         title = "Using the Spatial Configuration of the Data to Improve Estimation",
         journal = "The Journal of Real Estate Finance and Economics",
         year = "1997",
         volume = "14",
         pages = "333--340",
         doi = "10.1023/A:1007762613901")

bibentry(bibtype = "InCollection",
         key = "Quinlan:1992",
         author = person(given = "Ross",
                         family = "Quinlan"),
         title = "Learning with Continuous Classes",
         booktitle = "Proceedings of the Australian Joint Conference on Artificial Intelligence",
         publisher = "World Scientific",
         year = "1992",
         pages = "343--348",
         address = "Singapore")

bibentry(bibtype = "InProceedings",
         key = "Quinlan:1993",
         author = person(given = c("J.", "Ross"),
                         family = "Quinlan"),
         title = "Combining Instance-Based and Model-Based Learning",
         year = "1993",
         isbn = "1558603077",
         publisher = "Morgan Kaufmann Publishers Inc.",
         address = "San Francisco, CA, USA",
         booktitle = "Proceedings of the Tenth International Conference on International Conference on Machine Learning",
         pages = "236--243",
         numpages = "8",
         location = "Amherst, MA, USA",
         series = "ICML'93")

bibentry(bibtype = "InProceedings",
         key = "Renals+Rohwer:1989",
         author = c(person(given = "Steve",
                           family = "Renals"),
                    person(given = "Richard",
                           family = "Rohwer")),
         booktitle = "International 1989 Joint Conference on Neural Networks",
         title = "Phoneme Classification Experiments Using Radial Basis Functions",
         year = "1989",
         volume = "1",
         pages = "461--467",
         doi = "10.1109/IJCNN.1989.118620")

bibentry(bibtype = "Book",
         key = "Ripley:1996",
         author = person(given = c("Brian", "D."),
                         family = "Ripley"),
         title = "Pattern Recognition and Neural Networks",
         publisher = "Cambridge University Press",
         year = "1996",
         address = "Cambridge",
         doi = "10.1017/CBO9780511812651")

bibentry(bibtype = "InCollection",
         key = "Wahba+Gu+Wang:1995",
         author = c(person(given = "Grace",
                           family = "Wahba"),
                    person(given = "Chong",
                           family = "Gu"),
                    person(given = "Yuedong",
                           family = "Wang"),
                    person(given = "Richard",
                           family = "Chappell")),
         title = "Chapter Soft Classification, a.k.a.\\sspace{}Risk Estimation, via Penalized Log Likelihood and Smoothing Spline Analysis of Variance",
         booktitle = "The Mathematics of Generalization",
         publisher = "Addison-Wesley",
         year = "1995",
         editor = person(given = c("D.", "H."),
                         family = "Wolpert"),
         pages = "331--359",
         address = "Reading, MA")

bibentry(bibtype = "Article",
         key = "Wolberg+Mangasarian:1990",
         author = c(person(given = c("W.", "H."),
                           family = "Wolberg"),
                    person(given = c("O.", "L."),
                           family = "Mangasarian")),
         title = "Multisurface Method of Pattern Separation for Medical Diagnosis Applied to Breast Cytology",
         journal = "Proceedings of the National Academy of Sciences",
         volume = "87",
         number = "23",
         pages = "9193--9196",
         year = "1990",
         doi = "10.1073/pnas.87.23.9193")

bibentry(bibtype = "Misc",
         key = "Siebert:1987",
         author = person(given = "Paul",
                         family = "Siebert"),
         title = "Vehicle Recognition Using Rule Based Methods",
         year = "1987",
         note = "Turing Institute Research Memorandum TIRM-87-018")

bibentry(bibtype = "Article",
         key = "Sigillito+Wing+Hutton:1989",
         author = c(person(given = c("Vincent", "G."),
                           family = "Sigillito"),
                    person(given = "Simon",
                           family = "Wing"),
                    person(given = c("Larrie", "V."),
                           family = "Hutton"),
                    person(given = c("K.", "L."),
                           family = "Baker")),
         title = "Classification of Radar Returns from the Ionosphere Using Neural Networks",
         journal = "Johns Hopkins APL Technical Digest",
         year = "1989",
         volume = "10",
         number = "3",
         pages = "262--266",
         url = "https://secwww.jhuapl.edu/techdigest/content/techdigest/pdf/V10-N03/10-03-Sigillito_Class.pdf")

bibentry(bibtype = "InCollection",
         key = "Zhang:1992",
         title = "Selecting Typical Instances in Instance-Based Learning",
         editor = c(person(given = "Derek",
                           family = "Sleeman"),
                    person(given = "Peter",
                           family = "Edwards")),
         booktitle = "Machine Learning Proceedings 1992",
         publisher = "Morgan Kaufmann",
         address = "San Francisco (CA)",
         pages = "470--479",
         year = "1992",
         isbn = "978-1-55860-247-2",
         doi = "10.1016/B978-1-55860-247-2.50066-8",
         author = person(given = "Jianping",
                         family = "Zhang"))

bibentry(bibtype = "InCollection",
         key = "Tan+Eshelman:1988",
         title = "Using Weighted Networks to Represent Classification Knowledge in Noisy Domains",
         editor = person(given = "John",
                         family = "Laird"),
         booktitle = "Machine Learning Proceedings 1988",
         publisher = "Morgan Kaufmann",
         address = "San Francisco (CA)",
         pages = "121-134",
         year = "1988",
         isbn = "978-0-934613-64-4",
         doi = "10.1016/B978-0-934613-64-4.50018-9",
         author = c(person(given = "Ming",
                           family = "Tan"),
                    person(given = "Larry",
                           family = "Eshelman")))

bibentry(bibtype = "PhdThesis",
         key = "Towell:1991",
         author = person(given = c("Geoffrey", "G."),
                         family = "Towell"),
         title = "Symbolic Knowledge and Neural Networks: Insertion, Refinement, and Extraction",
         school = "University of Wisconsin Madison",
         year = "1991")

bibentry(bibtype = "InCollection",
         key = "Towell+Craven+Shavlik:1991",
         title = "Constructive Induction in Knowledge-Based Neural Networks",
         editor = c(person(given = c("Lawrence", "A."),
                           family = "Birnbaum"),
                    person(given = c("Gregg", "C."),
                           family = "Collins")),
         booktitle = "Machine Learning Proceedings 1991",
         publisher = "Morgan Kaufmann",
         address = "San Francisco (CA)",
         pages = "213--217",
         year = "1991",
         isbn = "978-1-55860-200-7",
         doi = "10.1016/B978-1-55860-200-7.50046-5",
         author = c(person(given = c("Geoffrey", "G."),
                           family = "Towell"),
                    person(given = c("Mark", "W."),
                           family = "Craven"),
                    person(given = c("Jude", "W."),
                           family = "Shavlik")))

bibentry(bibtype = "InProceedings",
         key = "Towell+Shavlik:1991",
         author = c(person(given = c("Geoffrey", "G."),
                           family = "Towell"),
                    person(given = c("Jude", "W."),
                           family = "Shavlik")),
         title = "Interpretation of Artificial Neural Networks: Mapping Knowledge-Based Neural Networks into Rules",
         year = "1991",
         isbn = "1558602224",
         publisher = "Morgan Kaufmann Publishers Inc.",
         address = "San Francisco, CA, USA",
         booktitle = "Proceedings of the 5th International Conference on Neural Information Processing Systems",
         pages = "977--984",
         numpages = "8",
         location = "Denver, Colorado",
         series = "NIPS'91")
